@@ -4,18 +4,18 @@ use strict;
 use Lemonldap::NG::Common::Conf::Constants;    #inherits
 use Lemonldap::NG::Common::Conf::Serializer;
 
-our $VERSION = '0.992';
+our $VERSION = '1.2.2_01';
 
 sub prereq {
     my $self = shift;
     unless ( $self->{dirName} ) {
-        $Lemonldap::NG::Common::Conf::msg =
-          '"dirName" is required in "File" configuration type !';
+        $Lemonldap::NG::Common::Conf::msg .=
+          '"dirName" is required in "File" configuration type ! \n';
         return 0;
     }
     unless ( -d $self->{dirName} ) {
-        $Lemonldap::NG::Common::Conf::msg =
-          "Directory \"$self->{dirName}\" does not exist !";
+        $Lemonldap::NG::Common::Conf::msg .=
+          "Directory \"$self->{dirName}\" does not exist ! \n";
         return 0;
     }
     1;
@@ -25,7 +25,7 @@ sub available {
     my $self = shift;
     opendir D, $self->{dirName};
     my @conf = readdir(D);
-    close D;
+    closedir D;
     @conf = sort { $a <=> $b } map { /lmConf-(\d+)/ ? $1 : () } @conf;
     return @conf;
 }
@@ -43,8 +43,8 @@ sub lock {
         return 0 if ( $self->isLocked );
     }
     unless ( open F, ">" . $self->{dirName} . "/lmConf.lock" ) {
-        $Lemonldap::NG::Common::Conf::msg =
-          "Unable to lock (" . $self->{dirName} . "/lmConf.lock)\n";
+        $Lemonldap::NG::Common::Conf::msg .=
+          "Unable to lock (" . $self->{dirName} . "/lmConf.lock) \n";
         return 0;
     }
     print F $$;
@@ -60,6 +60,7 @@ sub isLocked {
 sub unlock {
     my $self = shift;
     unlink $self->{dirName} . "/lmConf.lock";
+    1;
 }
 
 sub store {
@@ -70,7 +71,7 @@ sub store {
     unless ( open FILE,
         '>' . $self->{dirName} . "/lmConf-" . $fields->{cfgNum} )
     {
-        $Lemonldap::NG::Common::Conf::msg = "Open file failed: $!";
+        $Lemonldap::NG::Common::Conf::msg .= "Open file failed: $! \n";
         $self->unlock;
         return UNKNOWN_ERROR;
     }
