@@ -9,8 +9,9 @@ use strict;
 use Net::LDAP;
 use Lemonldap::NG::Common::Conf::Constants;    #inherits
 use Lemonldap::NG::Common::Conf::Serializer;
+use Encode;
 
-our $VERSION = '1.0.0';
+our $VERSION = '1.2.2_01';
 
 BEGIN {
     *Lemonldap::NG::Common::Conf::ldap = \&ldap;
@@ -20,8 +21,8 @@ sub prereq {
     my $self = shift;
     foreach ( 'ldapServer', 'ldapConfBase', 'ldapBindDN', 'ldapBindPassword' ) {
         unless ( $self->{$_} ) {
-            $Lemonldap::NG::Common::Conf::msg =
-              "$_ is required in LDAP configuration type";
+            $Lemonldap::NG::Common::Conf::msg .=
+              "$_ is required in LDAP configuration type \n";
             return 0;
         }
     }
@@ -29,14 +30,24 @@ sub prereq {
 }
 
 sub available {
-    my $self   = shift;
+    my $self = shift;
+
+    unless ( $self->ldap ) {
+        return 0;
+    }
+
     my $search = $self->ldap->search(
         base   => $self->{ldapConfBase},
         filter => '(objectClass=applicationProcess)',
         scope  => 'one',
         attrs  => ['cn'],
     );
-    $self->logError($search) if ( $search->code );
+
+    if ( $search->code ) {
+        $self->logError($search);
+        return 0;
+    }
+
     my @entries = $search->entries();
     my @conf;
     foreach (@entries) {
@@ -125,6 +136,11 @@ sub unlock {
 
 sub store {
     my ( $self, $fields ) = @_;
+
+    unless ( $self->ldap ) {
+        return 0;
+    }
+
     $fields = $self->serialize($fields);
 
     my $confName = "lmConf-" . $fields->{cfgNum};
@@ -133,6 +149,7 @@ sub store {
     # Store values as {key}value
     my @confValues;
     while ( my ( $k, $v ) = each(%$fields) ) {
+        $v = encodeLdapValue($v);
         push @confValues, "{$k}$v";
     }
 
@@ -145,7 +162,11 @@ sub store {
         ]
     );
 
-    $self->logError($add) if ( $add->code );
+    if ( $add->code ) {
+        $self->logError($add);
+        return 0;
+    }
+
     $self->ldap->unbind() && delete $self->{ldap};
     $self->unlock;
     return $fields->{cfgNum};
@@ -153,6 +174,11 @@ sub store {
 
 sub load {
     my ( $self, $cfgNum, $fields ) = @_;
+
+    unless ( $self->ldap ) {
+        return;
+    }
+
     my $f;
     my $confName = "lmConf-" . $cfgNum;
     my $confDN   = "cn=$confName," . $self->{ldapConfBase};
@@ -163,11 +189,17 @@ sub load {
         scope  => 'base',
         attrs  => ['description'],
     );
-    $self->logError($search) if ( $search->code );
+
+    if ( $search->code ) {
+        $self->logError($search);
+        return;
+    }
+
     my $entry      = $search->shift_entry();
     my @confValues = $entry->get_value('description');
     foreach (@confValues) {
         my ( $k, $v ) = ( $_ =~ /\{(.*?)\}(.*)/ );
+        $v = decodeLdapValue($v);
         if ($fields) {
             $f->{$k} = $v if ( grep { $_ eq $k } @$fields );
         }
@@ -182,6 +214,10 @@ sub load {
 sub delete {
     my ( $self, $cfgNum ) = @_;
 
+    unless ( $self->ldap ) {
+        return 0;
+    }
+
     my $confDN = "cn=lmConf-" . $cfgNum . "," . $self->{ldapConfBase};
     my $delete = $self->ldap->delete($confDN);
     $self->ldap->unbind() && delete $self->{ldap};
@@ -191,10 +227,38 @@ sub delete {
 sub logError {
     my $self           = shift;
     my $ldap_operation = shift;
-    $Lemonldap::NG::Common::Conf::msg =
+    $Lemonldap::NG::Common::Conf::msg .=
         "LDAP error "
       . $ldap_operation->code . ": "
-      . $ldap_operation->error . "\n";
+      . $ldap_operation->error . " \n";
+}
+
+# Helpers to have UTF-8 values in LDAP
+# and default encoding in configuration object
+sub encodeLdapValue {
+    my $value = shift;
+
+    eval {
+        my $safevalue = $value;
+        Encode::from_to( $safevalue, "utf8", "iso-8859-1", Encode::FB_CROAK );
+    };
+    if ($@) {
+        Encode::from_to( $value, "iso-8859-1", "utf8", Encode::FB_CROAK );
+        print STDERR "ENCODE VAL as $value\n";
+    }
+
+    return $value;
+
+}
+
+sub decodeLdapValue {
+    my $value = shift;
+
+    Encode::from_to( $value, "utf8", "iso-8859-1", Encode::FB_CROAK );
+    print STDERR "DECODE VAL as $value\n";
+
+    return $value;
+
 }
 
 1;
