@@ -4,7 +4,7 @@ use strict;
 use DBI;
 use Lemonldap::NG::Common::Conf::Constants;    #inherits
 
-our $VERSION = '0.992';
+our $VERSION = '1.2.2_01';
 our @ISA     = qw(Lemonldap::NG::Common::Conf::Constants);
 our ( @EXPORT, %EXPORT_TAGS );
 
@@ -55,7 +55,7 @@ sub _dbh {
     $self->{dbiTable} ||= "lmConfig";
     return $self->{_dbh} if ( $self->{_dbh} and $self->{_dbh}->ping );
     return DBI->connect_cached( $self->{dbiChain}, $self->{dbiUser},
-        $self->{dbiPassword}, { RaiseError => 1, AutoCommit => 1, } );
+        $self->{dbiPassword}, { RaiseError => 1, AutoCommit => 0, } );
 }
 
 sub lock {
@@ -69,6 +69,7 @@ sub lock {
             my @row = $sth->fetchrow_array;
             return $row[0] || 0;
         };
+        return 1;
     }
     else {
 
@@ -88,6 +89,7 @@ sub isLocked {
             my @row = $sth->fetchrow_array;
             return $row[0] ? 0 : 1;
         };
+        return 0;
     }
     else {
 
@@ -107,6 +109,7 @@ sub unlock {
             my @row = $sth->fetchrow_array;
             return $row[0] || 0;
         };
+        return 1;
     }
     else {
 
